@@ -4,7 +4,7 @@
 import sys
 
 
-def progress(count: int, total: int, status=''):
+def progress(count: int, total: int, status: str = '') -> None:
     bar_len = 60
     filled_len = int(round(bar_len * count / float(total)))
 
